@@ -41,6 +41,9 @@ FAILEDOPERATION = 'FailedOperation'
 # 异步任务状态异常。
 FAILEDOPERATION_ASYNCTASKSTATUSERROR = 'FailedOperation.AsyncTaskStatusError'
 
+# 审计不存在。
+FAILEDOPERATION_AUDITCONFIGNOTEXIST = 'FailedOperation.AuditConfigNotExist'
+
 # 实例互斥操作锁定失败,请稍后重试。
 FAILEDOPERATION_CDBINSTANCELOCKFAILERROR = 'FailedOperation.CdbInstanceLockFailError'
 
@@ -236,6 +239,9 @@ INTERNALERROR_TIMEWINDOWERROR = 'InternalError.TimeWindowError'
 # 交易系统错误。
 INTERNALERROR_TRADEERROR = 'InternalError.TradeError'
 
+# 操作失败。
+INTERNALERROR_TRANSACTIONBEGINERROR = 'InternalError.TransactionBeginError'
+
 # 未知错误。
 INTERNALERROR_UNDEFINEDERROR = 'InternalError.UndefinedError'
 
@@ -350,6 +356,12 @@ OPERATIONDENIED_ACTIONINPROCESS = 'OperationDenied.ActionInProcess'
 # 不支持的操作。
 OPERATIONDENIED_ACTIONNOTSUPPORT = 'OperationDenied.ActionNotSupport'
 
+# 已开启安全审计，至少保留一个全审计。
+OPERATIONDENIED_ATLEASTALLRULEAUDITPOLICYERROR = 'OperationDenied.AtLeastAllRuleAuditPolicyError'
+
+# 至少保留一个审计策略。
+OPERATIONDENIED_ATLEASTAUDITPOLICYERROR = 'OperationDenied.AtLeastAuditPolicyError'
+
 # 审计日志文件数超过最大限制数。
 OPERATIONDENIED_AUDITFILEOVERQUOTAERROR = 'OperationDenied.AuditFileOverQuotaError'
 
@@ -386,6 +398,9 @@ OPERATIONDENIED_AUDITTASKCONFLICTERROR = 'OperationDenied.AuditTaskConflictError
 # 当前RO组有RO实例处于非法状态，不允许执行当前操作。
 OPERATIONDENIED_CONFLICTROSTATUS = 'OperationDenied.ConflictRoStatus'
 
+# 当前只读组配置正在变更中，请勿重复发起请求。
+OPERATIONDENIED_CONFLICTSTATUS = 'OperationDenied.ConflictStatus'
+
 # 已开通安全审计,不支持规则审计。
 OPERATIONDENIED_DBBRAINPOLICYCONFLICT = 'OperationDenied.DBBrainPolicyConflict'
 
@@ -425,6 +440,9 @@ OPERATIONDENIED_OTHERODERINPROCESS = 'OperationDenied.OtherOderInProcess'
 # 资源配额超限。
 OPERATIONDENIED_OVERQUOTA = 'OperationDenied.OverQuota'
 
+# 数据库代理升级任务中，不允许该操作。
+OPERATIONDENIED_PROXYUPGRADETASKSTATUSERROR = 'OperationDenied.ProxyUpgradeTaskStatusError'
+
 # 结果集超过限制，请缩小检索范围。
 OPERATIONDENIED_RESULTOVERLIMIT = 'OperationDenied.ResultOverLimit'
 
