@@ -24,7 +24,7 @@ class AudioResult(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param HitFlag: 该字段用于返回审核内容是否命中审核模型；取值：0（**未命中**）、1（**命中**）。
 注意：此字段可能返回 null，表示取不到有效值。
         :type HitFlag: int
@@ -59,6 +59,9 @@ class AudioResult(AbstractModel):
         :param LanguageResults: 该字段用于返回音频小语种检测的详细审核结果。具体结果内容请参见AudioResultDetailLanguageResult数据结构的细节描述。
 注意：此字段可能返回 null，表示取不到有效值。
         :type LanguageResults: list of AudioResultDetailLanguageResult
+        :param SubLabel: 该字段用于返回当前标签（Lable）下的二级标签。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type SubLabel: str
         """
         self.HitFlag = None
         self.Label = None
@@ -71,6 +74,7 @@ class AudioResult(AbstractModel):
         self.TextResults = None
         self.MoanResults = None
         self.LanguageResults = None
+        self.SubLabel = None
 
 
     def _deserialize(self, params):
@@ -100,6 +104,7 @@ class AudioResult(AbstractModel):
                 obj = AudioResultDetailLanguageResult()
                 obj._deserialize(item)
                 self.LanguageResults.append(obj)
+        self.SubLabel = params.get("SubLabel")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -115,7 +120,7 @@ class AudioResultDetailLanguageResult(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Label: 该字段用于返回对应的语言种类信息。
 注意：此字段可能返回 null，表示取不到有效值。
         :type Label: str
@@ -160,7 +165,7 @@ class AudioResultDetailMoanResult(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Label: 该字段用于返回检测结果需要检测的内容类型，此处固定为**Moan**（呻吟）以调用呻吟检测功能。
 注意：此字段可能返回 null，表示取不到有效值。
         :type Label: str
@@ -172,12 +177,16 @@ class AudioResultDetailMoanResult(AbstractModel):
         :type EndTime: float
         :param SubLabelCode: *内测中，敬请期待*
         :type SubLabelCode: str
+        :param SubLabel: 该字段用于返回当前标签（Lable）下的二级标签。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type SubLabel: str
         """
         self.Label = None
         self.Score = None
         self.StartTime = None
         self.EndTime = None
         self.SubLabelCode = None
+        self.SubLabel = None
 
 
     def _deserialize(self, params):
@@ -186,6 +195,7 @@ class AudioResultDetailMoanResult(AbstractModel):
         self.StartTime = params.get("StartTime")
         self.EndTime = params.get("EndTime")
         self.SubLabelCode = params.get("SubLabelCode")
+        self.SubLabel = params.get("SubLabel")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -201,7 +211,7 @@ class AudioResultDetailTextResult(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Label: 该字段用于返回检测结果所对应的恶意标签。<br>返回值：**Normal**：正常，**Porn**：色情，**Abuse**：谩骂，**Ad**：广告，**Custom**：自定义违规；以及其他令人反感、不安全或不适宜的内容类型。
 注意：此字段可能返回 null，表示取不到有效值。
         :type Label: str
@@ -224,6 +234,9 @@ class AudioResultDetailTextResult(AbstractModel):
         :param LibType: 该字段用于返回自定义关键词对应的词库类型，取值为**1**（黑白库）和**2**（自定义关键词库），若未配置自定义关键词库,则默认值为1（黑白库匹配）。
 注意：此字段可能返回 null，表示取不到有效值。
         :type LibType: int
+        :param SubLabel: 该字段用于返回当前标签（Lable）下的二级标签。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type SubLabel: str
         """
         self.Label = None
         self.Keywords = None
@@ -232,6 +245,7 @@ class AudioResultDetailTextResult(AbstractModel):
         self.Score = None
         self.Suggestion = None
         self.LibType = None
+        self.SubLabel = None
 
 
     def _deserialize(self, params):
@@ -242,6 +256,7 @@ class AudioResultDetailTextResult(AbstractModel):
         self.Score = params.get("Score")
         self.Suggestion = params.get("Suggestion")
         self.LibType = params.get("LibType")
+        self.SubLabel = params.get("SubLabel")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -257,7 +272,7 @@ class AudioSegments(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param OffsetTime: 该字段用于返回音频片段的开始时间，单位为秒。对于点播文件，该参数代表对应音频相对于完整音轨的偏移时间，如0（代表不偏移），5（音轨开始后5秒），10（音轨开始后10秒）；对于直播文件，该参数则返回对应音频片段开始时的Unix时间戳，如：1594650717。
 注意：此字段可能返回 null，表示取不到有效值。
         :type OffsetTime: str
@@ -290,7 +305,7 @@ class BucketInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Bucket: 该字段用于标识腾讯云对象存储的存储桶名称,关于文件桶的详细信息敬请参考 [腾讯云存储相关说明](https://cloud.tencent.com/document/product/436/44352)。
         :type Bucket: str
         :param Region: 该字段用于标识腾讯云对象存储的托管机房的分布地区，对象存储 COS 的数据存放在这些地域的存储桶中。
@@ -322,7 +337,7 @@ class CancelTaskRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param TaskId: 该字段表示创建视频审核任务后返回的任务ID（在Results参数中），用于标识需要取消的审核任务。
         :type TaskId: str
         """
@@ -346,7 +361,7 @@ class CancelTaskResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
@@ -363,7 +378,7 @@ class CreateVideoModerationTaskRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Type: 该参数用于传入审核任务的任务类型，取值：**VIDEO**（点播视频），**LIVE_VIDEO**（直播视频）。
         :type Type: str
         :param Tasks: 该字段表示输入的视频审核任务信息，具体输入内容请参见TaskInput数据结构的详细描述。<br> 备注：最多同时可创建**10个任务**。
@@ -412,7 +427,7 @@ class CreateVideoModerationTaskResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Results: 该字段用于返回任务创建的结果，具体输出内容请参见TaskResult数据结构的详细描述。
 注意：此字段可能返回 null，表示取不到有效值。
         :type Results: list of TaskResult
@@ -439,7 +454,7 @@ class DescribeTaskDetailRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param TaskId: 该字段表示创建视频审核任务后返回的任务ID（在Results参数中），用于标识需要查询任务详情的审核任务。
 <br>备注：查询接口单次最大查询量为**20条每次**。
         :type TaskId: str
@@ -468,7 +483,7 @@ class DescribeTaskDetailResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param TaskId: 该字段用于返回创建视频审核任务后返回的任务ID（在Results参数中），用于标识需要查询任务详情的审核任务。
 注意：此字段可能返回 null，表示取不到有效值。
         :type TaskId: str
@@ -485,7 +500,7 @@ class DescribeTaskDetailResponse(AbstractModel):
 <br>取值：**FINISH**（任务已完成）、**PENDING** （任务等待中）、**RUNNING** （任务进行中）、**ERROR** （任务出错）、**CANCELLED** （任务已取消）。
 注意：此字段可能返回 null，表示取不到有效值。
         :type Status: str
-        :param Type: 该字段用于返回调用视频审核接口时输入的视频审核类型，取值为：**VIDEO**（点播音频）和**LIVE_VIDEO**（直播音频），默认值为VIDEO。
+        :param Type: 该字段用于返回调用视频审核接口时输入的视频审核类型，取值为：**VIDEO**（点播视频）和**LIVE_VIDEO**（直播视频），默认值为VIDEO。
 注意：此字段可能返回 null，表示取不到有效值。
         :type Type: str
         :param Suggestion: 该字段用于返回基于恶意标签的后续操作建议。当您获取到判定结果后，返回值表示系统推荐的后续操作；建议您按照业务所需，对不同违规类型与建议值进行处理。<br>返回值：**Block**：建议屏蔽，**Review** ：建议人工复审，**Pass**：建议通过
@@ -587,7 +602,7 @@ class DescribeTasksRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Limit: 该参数表示任务列表每页展示的任务条数，**默认值为10**（每页展示10条任务）。
         :type Limit: int
         :param Filter: 该参数表示任务筛选器的输入参数，可根据业务类型、审核文件类型、处理建议及任务状态筛选想要查看的审核任务，具体参数内容请参见TaskFilter数据结构的详细描述。
@@ -629,7 +644,7 @@ class DescribeTasksResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Total: 该字段用于返回当前查询的任务总量，格式为int字符串。
 注意：此字段可能返回 null，表示取不到有效值。
         :type Total: str
@@ -666,7 +681,7 @@ class ImageResult(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param HitFlag: 该参数用于标识审核内容是否命中恶意标签，取值：0（**未命中**）和1（**命中**）。
 注意：此字段可能返回 null，表示取不到有效值。
         :type HitFlag: int
@@ -689,6 +704,9 @@ class ImageResult(AbstractModel):
         :param Extra: 该字段用于返回输入参数中的额外附加信息（Extra），如未配置则默认返回值为空。<br>备注：不同客户或Biztype下返回信息不同，如需配置该字段请提交工单咨询或联系售后专员处理。
 注意：此字段可能返回 null，表示取不到有效值。
         :type Extra: str
+        :param SubLabel: 该字段用于返回当前标签（Lable）下的二级标签。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type SubLabel: str
         """
         self.HitFlag = None
         self.Label = None
@@ -697,6 +715,7 @@ class ImageResult(AbstractModel):
         self.Results = None
         self.Url = None
         self.Extra = None
+        self.SubLabel = None
 
 
     def _deserialize(self, params):
@@ -712,6 +731,7 @@ class ImageResult(AbstractModel):
                 self.Results.append(obj)
         self.Url = params.get("Url")
         self.Extra = params.get("Extra")
+        self.SubLabel = params.get("SubLabel")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -727,7 +747,7 @@ class ImageResultResult(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Scene: 该字段用于返回检测结果所对应的恶意场景。返回值：**Normal**：正常，**Porn**：色情，**Abuse**：谩骂，**AppLogo**：广告台标，**Custom**：自定义违规，以及其他令人反感、不安全或不适宜的内容类型。
 注意：此字段可能返回 null，表示取不到有效值。
         :type Scene: str
@@ -798,7 +818,7 @@ class ImageResultsResultDetail(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Name: 该字段用于返回调用视频审核接口时传入的TaskInput参数中的任务名称，方便任务的识别与管理。
 注意：此字段可能返回 null，表示取不到有效值。
         :type Name: str
@@ -871,7 +891,7 @@ class ImageResultsResultDetailLocation(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param X: 该参数用于标识OCR检测框左上角位置的**横坐标**（x）所在的像素位置，结合剩余参数可唯一确定检测框的大小和位置。
 注意：此字段可能返回 null，表示取不到有效值。
         :type X: float
@@ -916,7 +936,7 @@ class ImageSegments(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param OffsetTime: 该字段用于返回视频片段的截帧时间，单位为秒。对于点播文件，该参数代表对应截取图片相对于视频的偏移时间，如0（代表不偏移），5（视频开始后5秒），10（视频开始后10秒）；对于直播文件，该参数则返回对应图片的Unix时间戳，如：1594650717。
         :type OffsetTime: str
         :param Result: 该字段用于返回视频片段的具体截帧审核结果，详细内容敬请参考ImageResult数据结构的描述。
@@ -946,7 +966,7 @@ class InputInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Type: 该字段表示文件访问类型，取值为**URL**（资源链接）和**COS** (腾讯云对象存储)。
 注意：此字段可能返回 null，表示取不到有效值。
         :type Type: str
@@ -981,7 +1001,7 @@ class MediaInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Duration: 该字段用于返回对传入的视频流进行分片的片段时长，单位为秒。**默认值为5秒**，支持用户自定义配置。<br>备注：仅在审核文件为流媒体时生效；此字段返回0则代表未取到有效值。
         :type Duration: int
         """
@@ -1005,7 +1025,7 @@ class StorageInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Type: 该字段表示文件访问类型，取值为**URL**（资源链接）和**COS** (腾讯云对象存储)；该字段应当与传入的访问类型相对应，可用于强校验并方便系统快速识别访问地址；若不传入此参数，则默认值为URL，此时系统将自动判定访问地址类型。
         :type Type: str
         :param Url: 该字段表示文件访问的链接地址，格式为标准URL格式。<br> 备注：当Type为URL时此字段不为空，该参数与BucketInfo参数须传入其中之一
@@ -1039,7 +1059,7 @@ class TaskData(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param DataId: 该字段用于返回视频审核任务数据所对应的数据ID，方便后续查询和管理审核任务。
 注意：此字段可能返回 null，表示取不到有效值。
         :type DataId: str
@@ -1119,7 +1139,7 @@ class TaskFilter(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param BizType: 该字段用于传入任务对应的业务类型供筛选器进行筛选。Biztype为策略的具体的编号，用于接口调度，在内容安全控制台中可配置。不同Biztype关联不同的业务场景与审核策略，调用前请确认正确的Biztype。Biztype仅为**数字、字母与下划线的组合**，长度为3-32个字符。<br>备注：在不传入该参数时筛选器默认不筛选业务类型。
 注意：此字段可能返回 null，表示取不到有效值。
         :type BizType: list of str
@@ -1156,7 +1176,7 @@ class TaskInput(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param DataId: 选填参数，该字段表示您为待检测对象分配的数据ID，传入后可方便您对文件进行标识和管理。<br>取值：由英文字母（大小写均可）、数字及四个特殊符号（_，-，@，#）组成，**长度不超过64个字符**。
         :type DataId: str
         :param Name: 选填参数，该字段表示审核任务所对应的任务名称，方便后续查询和管理审核任务。
@@ -1190,7 +1210,7 @@ class TaskLabel(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Label: 该字段用于返回检测结果所对应的恶意标签。<br>返回值：**Normal**：正常，**Porn**：色情，**Abuse**：谩骂，**Ad**：广告，**Custom**：自定义违规；以及其他令人反感、不安全或不适宜的内容类型。
 注意：此字段可能返回 null，表示取不到有效值。
         :type Label: str
@@ -1200,16 +1220,21 @@ class TaskLabel(AbstractModel):
         :param Score: 该字段用于返回当前标签（Label）下的置信度，取值范围：0（**置信度最低**）-100（**置信度最高** ），越高代表文本越有可能属于当前返回的标签；如：*色情 99*，则表明该文本非常有可能属于色情内容；*色情 0*，则表明该文本不属于色情内容。
 注意：此字段可能返回 null，表示取不到有效值。
         :type Score: int
+        :param SubLabel: 该字段用于返回当前标签（Lable）下的二级标签。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type SubLabel: str
         """
         self.Label = None
         self.Suggestion = None
         self.Score = None
+        self.SubLabel = None
 
 
     def _deserialize(self, params):
         self.Label = params.get("Label")
         self.Suggestion = params.get("Suggestion")
         self.Score = params.get("Score")
+        self.SubLabel = params.get("SubLabel")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -1225,7 +1250,7 @@ class TaskResult(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param DataId: 该字段用于返回创建视频审核任务时在TaskInput结构内传入的DataId，用于标识具体审核任务。
 注意：此字段可能返回 null，表示取不到有效值。
         :type DataId: str
